# ----------------------- broomExtra -------------------------------------

#' @export
#' @importFrom broomExtra grouped_tidy
broomExtra::grouped_tidy

#' @export
#' @importFrom broomExtra grouped_glance
broomExtra::grouped_glance

#' @export
#' @importFrom broomExtra grouped_augment
broomExtra::grouped_augment

# ----------------------- tidyverse -------------------------------------

#' @export
#' @importFrom magrittr "%>%"
magrittr::`%>%`

#' @export
#' @importFrom magrittr "%<>%"
magrittr::`%<>%`

#' @export
#' @importFrom magrittr "%$%"
magrittr::`%$%`

#' @export
#' @importFrom tibble tibble
tibble::tibble
